==> node-sinon_9.0.3+ds+~cs48.19.16.orig-sinonjsreferee-sinon.tar.xz: referee-sinon-7.1.0/CHANGES.md <==
# Changes

## 7.1.0

- [`91ef947`](https://github.com/sinonjs/referee-sinon/commit/91ef947a8b9508c7dcd755c5a89763b580a99e61)
  Fix issues with undefined fakes (Maximilian Antoni)
    >
    > The tests where covering these cases, but the wrong regexp handling in
    > referee exception assertion used to let the tests pass anyway.
    >
    > See https://github.com/sinonjs/referee/pull/146
    >
- [`f5d9496`](https://github.com/sinonjs/referee-sinon/commit/f5d9496c4646426d00e38087cc48e6464c53bdee)
  Upgrade referee to v6 (Maximilian Antoni)

_Released by [Maximilian Antoni](https://github.com/mantoni) on 2020-06-17._

## 7.0.2

- [`54f4e5d`](https://github.com/sinonjs/referee-sinon/commit/54f4e5d7cd208a0a566bd5697c678cb44a48633f)
  Fix sinon assertions with matchers (#83) (Maximilian Antoni)
    >
    > * Add failing test for issue with 2 samsam versions
    > * Upgrade referee to v5
    > * Reinstall dependencies
    >

_Released by [Maximilian Antoni](https://github.com/mantoni) on 2020-02-28._

## 7.0.1

- [`78d7894`](https://github.com/sinonjs/referee-sinon/commit/78d7894556d0723b02e84d7cb44acccc834146d0)
  Bump @sinonjs/formatio (Morgan Roderick)
- [`1afe7d4`](https://github.com/sinonjs/referee-sinon/commit/1afe7d49879668b3903b183a3b9271aacb12db8b)
  Bump Sinon to latest (Morgan Roderick)

_Released on 2020-02-20._

## 7.0.0

- [`89b3f8d`](https://github.com/sinonjs/referee-sinon/commit/89b3f8d01ee44244d7322b11d646851960302994)
  Drop Node 8 support (Morgan Roderick)
    >
    > As can be seen at https://github.com/nodejs/Release, Node 8 reached
    > "end" of life on 2019-12-31, and is no longer actively supported.
    >
    > We will stop testing in Node 8 and start testing in Node 13, which will
    > become the next LTS release from April 2020.
    >

_Released on 2020-02-19._

## 6.0.1

- [`fb8c3d3`](https://github.com/sinonjs/referee-sinon/commit/fb8c3d3355a5d31434b01f291c373154330a0502)
  Upgrade Sinon to 8.0.3 (Morgan Roderick)
    >
    > Fixes #64
    >
- [`d00bf9e`](https://github.com/sinonjs/referee-sinon/commit/d00bf9ecb5680e275ac00a127b97016c277d0e8a)
  Add failing test for formatting fakes (Maximilian Antoni)
- [`3cc1c8e`](https://github.com/sinonjs/referee-sinon/commit/3cc1c8ed1501137a943cfc6ea39993385e3f8609)
  Bump rollup from 1.27.8 to 1.27.14 (dependabot-preview[bot])
    >
    > Bumps [rollup](https://github.com/rollup/rollup) from 1.27.8 to 1.27.14.
    > - [Release notes](https://github.com/rollup/rollup/releases)
    > - [Changelog](https://github.com/rollup/rollup/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/rollup/rollup/compare/v1.27.8...v1.27.14)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`2c17852`](https://github.com/sinonjs/referee-sinon/commit/2c178525475c18fba6eb195f5324204c9c89c9fd)
  Bump sinon from 8.0.1 to 8.0.2 (dependabot-preview[bot])
    >
    > Bumps [sinon](https://github.com/sinonjs/sinon) from 8.0.1 to 8.0.2.
    > - [Release notes](https://github.com/sinonjs/sinon/releases)
    > - [Changelog](https://github.com/sinonjs/sinon/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/sinonjs/sinon/compare/v8.0.1...v8.0.2)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`d7e27eb`](https://github.com/sinonjs/referee-sinon/commit/d7e27eb9e8164450af7387305a9aed015c91e8bd)
  Bump eslint from 6.7.2 to 6.8.0 (dependabot-preview[bot])
    >
    > Bumps [eslint](https://github.com/eslint/eslint) from 6.7.2 to 6.8.0.
    > - [Release notes](https://github.com/eslint/eslint/releases)
    > - [Changelog](https://github.com/eslint/eslint/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/eslint/eslint/compare/v6.7.2...v6.8.0)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`9274f0a`](https://github.com/sinonjs/referee-sinon/commit/9274f0a3c43e98dc37411ca658e233ace9ceedb1)
  Bump lint-staged from 9.4.1 to 9.5.0 (dependabot-preview[bot])
    >
    > Bumps [lint-staged](https://github.com/okonet/lint-staged) from 9.4.1 to 9.5.0.
    > - [Release notes](https://github.com/okonet/lint-staged/releases)
    > - [Commits](https://github.com/okonet/lint-staged/compare/v9.4.1...v9.5.0)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`14f3447`](https://github.com/sinonjs/referee-sinon/commit/14f3447a687ed8777f70d17486d151fe702051d8)
  Bump eslint-config-prettier from 6.7.0 to 6.9.0 (dependabot-preview[bot])
    >
    > Bumps [eslint-config-prettier](https://github.com/prettier/eslint-config-prettier) from 6.7.0 to 6.9.0.
    > - [Release notes](https://github.com/prettier/eslint-config-prettier/releases)
    > - [Changelog](https://github.com/prettier/eslint-config-prettier/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/prettier/eslint-config-prettier/commits/v6.9.0)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`77a9dd2`](https://github.com/sinonjs/referee-sinon/commit/77a9dd206256525d6bfac44b59e00bd2a795eebd)
  Bump eslint-plugin-prettier from 3.1.1 to 3.1.2 (dependabot-preview[bot])
    >
    > Bumps [eslint-plugin-prettier](https://github.com/prettier/eslint-plugin-prettier) from 3.1.1 to 3.1.2.
    > - [Release notes](https://github.com/prettier/eslint-plugin-prettier/releases)
    > - [Changelog](https://github.com/prettier/eslint-plugin-prettier/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/prettier/eslint-plugin-prettier/compare/v3.1.1...v3.1.2)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`8f04bd1`](https://github.com/sinonjs/referee-sinon/commit/8f04bd1220d006f29a249b7f23bc8d70fa1e9f5b)
  Bump nyc from 14.1.1 to 15.0.0 (dependabot-preview[bot])
    >
    > Bumps [nyc](https://github.com/istanbuljs/nyc) from 14.1.1 to 15.0.0.
    > - [Release notes](https://github.com/istanbuljs/nyc/releases)
    > - [Changelog](https://github.com/istanbuljs/nyc/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/istanbuljs/nyc/compare/v14.1.1...v15.0.0)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`1c2c2b8`](https://github.com/sinonjs/referee-sinon/commit/1c2c2b89719e7ad4c5aba058f0fb951e00ed6d92)
  6.0.0 (Morgan Roderick)

_Released on 2020-01-06._

## 6.0.0

- [`1f46f90`](https://github.com/sinonjs/referee-sinon/commit/1f46f9028845b2e03dd14438d560d1c9b83401cb)
  Upgrade to Referee 4 and Sinon 8 (Maximilian Antoni)

_Released on 2019-12-23._

==> node-sinon_9.2.0+ds+~cs54.23.21.orig-sinonjsreferee-sinon.tar.xz: referee-sinon-7.3.0/CHANGES.md <==
# Changes

## 7.3.0

- [`8b0efed`](https://github.com/sinonjs/referee-sinon/commit/8b0efed86f13ec01a683cc1ed12bda0a18ea776d)
  Replace formatio with util inspect (#98) (Maximilian Antoni)

_Released by [Maximilian Antoni](https://github.com/mantoni) on 2020-10-06._

## 7.2.0

- [`160b5bf`](https://github.com/sinonjs/referee-sinon/commit/160b5bfce23bb8a4100c9e2af084fb1a16a72930)
  Sinon 9.1 (#96) (Maximilian Antoni)
    >
    > Add `calledOnceWithMatch` assertion
    >

_Released by [Maximilian Antoni](https://github.com/mantoni) on 2020-10-01._

## 7.1.0

- [`91ef947`](https://github.com/sinonjs/referee-sinon/commit/91ef947a8b9508c7dcd755c5a89763b580a99e61)
  Fix issues with undefined fakes (Maximilian Antoni)
    >
    > The tests where covering these cases, but the wrong regexp handling in
    > referee exception assertion used to let the tests pass anyway.
    >
    > See https://github.com/sinonjs/referee/pull/146
    >
- [`f5d9496`](https://github.com/sinonjs/referee-sinon/commit/f5d9496c4646426d00e38087cc48e6464c53bdee)
  Upgrade referee to v6 (Maximilian Antoni)

_Released by [Maximilian Antoni](https://github.com/mantoni) on 2020-06-17._

## 7.0.2

- [`54f4e5d`](https://github.com/sinonjs/referee-sinon/commit/54f4e5d7cd208a0a566bd5697c678cb44a48633f)
  Fix sinon assertions with matchers (#83) (Maximilian Antoni)
    >
    > * Add failing test for issue with 2 samsam versions
    > * Upgrade referee to v5
    > * Reinstall dependencies
    >

_Released by [Maximilian Antoni](https://github.com/mantoni) on 2020-02-28._

## 7.0.1

- [`78d7894`](https://github.com/sinonjs/referee-sinon/commit/78d7894556d0723b02e84d7cb44acccc834146d0)
  Bump @sinonjs/formatio (Morgan Roderick)
- [`1afe7d4`](https://github.com/sinonjs/referee-sinon/commit/1afe7d49879668b3903b183a3b9271aacb12db8b)
  Bump Sinon to latest (Morgan Roderick)

_Released on 2020-02-20._

## 7.0.0

- [`89b3f8d`](https://github.com/sinonjs/referee-sinon/commit/89b3f8d01ee44244d7322b11d646851960302994)
  Drop Node 8 support (Morgan Roderick)
    >
    > As can be seen at https://github.com/nodejs/Release, Node 8 reached
    > "end" of life on 2019-12-31, and is no longer actively supported.
    >
    > We will stop testing in Node 8 and start testing in Node 13, which will
    > become the next LTS release from April 2020.
    >

_Released on 2020-02-19._

## 6.0.1

- [`fb8c3d3`](https://github.com/sinonjs/referee-sinon/commit/fb8c3d3355a5d31434b01f291c373154330a0502)
  Upgrade Sinon to 8.0.3 (Morgan Roderick)
    >
    > Fixes #64
    >
- [`d00bf9e`](https://github.com/sinonjs/referee-sinon/commit/d00bf9ecb5680e275ac00a127b97016c277d0e8a)
  Add failing test for formatting fakes (Maximilian Antoni)
- [`3cc1c8e`](https://github.com/sinonjs/referee-sinon/commit/3cc1c8ed1501137a943cfc6ea39993385e3f8609)
  Bump rollup from 1.27.8 to 1.27.14 (dependabot-preview[bot])
    >
    > Bumps [rollup](https://github.com/rollup/rollup) from 1.27.8 to 1.27.14.
    > - [Release notes](https://github.com/rollup/rollup/releases)
    > - [Changelog](https://github.com/rollup/rollup/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/rollup/rollup/compare/v1.27.8...v1.27.14)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`2c17852`](https://github.com/sinonjs/referee-sinon/commit/2c178525475c18fba6eb195f5324204c9c89c9fd)
  Bump sinon from 8.0.1 to 8.0.2 (dependabot-preview[bot])
    >
    > Bumps [sinon](https://github.com/sinonjs/sinon) from 8.0.1 to 8.0.2.
    > - [Release notes](https://github.com/sinonjs/sinon/releases)
    > - [Changelog](https://github.com/sinonjs/sinon/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/sinonjs/sinon/compare/v8.0.1...v8.0.2)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`d7e27eb`](https://github.com/sinonjs/referee-sinon/commit/d7e27eb9e8164450af7387305a9aed015c91e8bd)
  Bump eslint from 6.7.2 to 6.8.0 (dependabot-preview[bot])
    >
    > Bumps [eslint](https://github.com/eslint/eslint) from 6.7.2 to 6.8.0.
    > - [Release notes](https://github.com/eslint/eslint/releases)
    > - [Changelog](https://github.com/eslint/eslint/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/eslint/eslint/compare/v6.7.2...v6.8.0)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`9274f0a`](https://github.com/sinonjs/referee-sinon/commit/9274f0a3c43e98dc37411ca658e233ace9ceedb1)
  Bump lint-staged from 9.4.1 to 9.5.0 (dependabot-preview[bot])
    >
    > Bumps [lint-staged](https://github.com/okonet/lint-staged) from 9.4.1 to 9.5.0.
    > - [Release notes](https://github.com/okonet/lint-staged/releases)
    > - [Commits](https://github.com/okonet/lint-staged/compare/v9.4.1...v9.5.0)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`14f3447`](https://github.com/sinonjs/referee-sinon/commit/14f3447a687ed8777f70d17486d151fe702051d8)
  Bump eslint-config-prettier from 6.7.0 to 6.9.0 (dependabot-preview[bot])
    >
    > Bumps [eslint-config-prettier](https://github.com/prettier/eslint-config-prettier) from 6.7.0 to 6.9.0.
    > - [Release notes](https://github.com/prettier/eslint-config-prettier/releases)
    > - [Changelog](https://github.com/prettier/eslint-config-prettier/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/prettier/eslint-config-prettier/commits/v6.9.0)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`77a9dd2`](https://github.com/sinonjs/referee-sinon/commit/77a9dd206256525d6bfac44b59e00bd2a795eebd)
  Bump eslint-plugin-prettier from 3.1.1 to 3.1.2 (dependabot-preview[bot])
    >
    > Bumps [eslint-plugin-prettier](https://github.com/prettier/eslint-plugin-prettier) from 3.1.1 to 3.1.2.
    > - [Release notes](https://github.com/prettier/eslint-plugin-prettier/releases)
    > - [Changelog](https://github.com/prettier/eslint-plugin-prettier/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/prettier/eslint-plugin-prettier/compare/v3.1.1...v3.1.2)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`8f04bd1`](https://github.com/sinonjs/referee-sinon/commit/8f04bd1220d006f29a249b7f23bc8d70fa1e9f5b)
  Bump nyc from 14.1.1 to 15.0.0 (dependabot-preview[bot])
    >
    > Bumps [nyc](https://github.com/istanbuljs/nyc) from 14.1.1 to 15.0.0.
    > - [Release notes](https://github.com/istanbuljs/nyc/releases)
    > - [Changelog](https://github.com/istanbuljs/nyc/blob/master/CHANGELOG.md)
    > - [Commits](https://github.com/istanbuljs/nyc/compare/v14.1.1...v15.0.0)
    >
    > Signed-off-by: dependabot-preview[bot] <support@dependabot.com>
- [`1c2c2b8`](https://github.com/sinonjs/referee-sinon/commit/1c2c2b89719e7ad4c5aba058f0fb951e00ed6d92)
  6.0.0 (Morgan Roderick)

_Released on 2020-01-06._

## 6.0.0

- [`1f46f90`](https://github.com/sinonjs/referee-sinon/commit/1f46f9028845b2e03dd14438d560d1c9b83401cb)
  Upgrade to Referee 4 and Sinon 8 (Maximilian Antoni)

_Released on 2019-12-23._
